@@ -25,6 +25,7 @@ import os
 import tkinter as tk
 import tkinter.font as tkFont
 import queue
+from functools import partial
 
 from pyworkflow.object import Object
 import pyworkflow as pw
@@ -245,7 +246,7 @@ class Window:
     It will encapsulates some basic creation and 
     setup functions. """
     # To allow plugins to add their own menus
-    _pluginMenus = list()
+    _pluginMenus = dict()
 
     def __init__(self, title='', masterWindow=None, weight=True,
                  minsize=(500, 300), icon=Icon.SCIPION_ICON, **kwargs):
@@ -439,15 +440,18 @@ class Window:
             menu.add_cascade(label="Others", menu=submenu)
 
             # For each plugin menu
-            for label, callback, icon in self._pluginMenus:
+            for label in self._pluginMenus:
                 submenu.add_command(label=label, compound=tk.LEFT,
-                                    image=self.getImage(icon),
-                                    command=callback)
+                                    image=self.getImage(self._pluginMenus.get(label)[1]),
+                                    command=partial(self.plugin_callback, label))
+
+    def plugin_callback(self, label):
+        return self._pluginMenus.get(label)[0](self)
 
     @classmethod
     def registerPluginMenu(cls, label, callback, icon=None):
         # TODO: have a proper model instead of a tuple?
-        cls._pluginMenus.append((label, callback, icon))
+        cls._pluginMenus[label] = (callback, icon)
 
     def showError(self, msg, header="Error", exception=None):
         """Pops up a dialog with the error message
